==> bodhi-cli-0.7.7.tgz: package/lib/controllers/RemoteTypeController.js <==
module.exports = function(project, options){

    var _  = require('../utils.js')
        , path    = require('path')
        , fs      = require('fs-extra')
        , Views   = require('../views/http.js')
        ;

    var ENDPOINT = 'types';

    /**
     * Fetch the object from the server and write to a file
     */
    function save(env, typeName, opr){
        var client = env.createClient();
        try{
            var model = fs.readJsonFileSync(asFilePath(typeName));
            model.namespace = env.namespace;
            client[opr](ENDPOINT, model, function(err, response, body){
                if(err) {
                    console.log('operation failed');
                    return;
                }
                if(response.statusCode === 422){
                    console.log('operation returned ' + response.statusCode);
                    console.log(body);
                } else {
                    console.log('operation returned ' + response.statusCode);
                }
            });
        } catch (err){
            console.log('No such model %s', typeName)
        }
        console.log(client.buildUri(asUrlPath(typeName)));
    }

    function create(env, typeName){
        return save(env, typeName, 'post');
    }

    function update(env, typeName){
        return save(env, typeName, 'put');
    }

    /**
     * Show a remote model
     */
    function get(env, typeName, spec){
        env.createClient().get(
            asUrlPath(typeName), Views(spec).entity
        );
    }

    /**
     * Fetch the object from the server and write to a file
     */
    function download(env, typeName){
        env.createClient().pull(asUrlPath(typeName), asFilePath(typeName));
        console.log(asFilePath(typeName));
    }

    /**
     * List the models
     */
    function list(env){
        env.createClient().get(ENDPOINT, function(err, response, body) {
            if(err){
                console.log("Error", err);
            } else {
                var json = JSON.parse(body);
                console.log(_.pluck(json, "name").sort());
            }
        });
    }

    function listProps(env, name){
        env.createClient().get(asUrlPath(name), function(err, response, body) {
                if(err){
                    console.log("Error", err);
                }
                var json = JSON.parse(body);
                var properties = [];
                _.forEach(json.properties, function(value, key, list){
                    if(!_.startsWith(key, 'rbc_') || !_.startsWith(key, 'sys_')){
                        console.log(key);
                    }
                })
        });
    }

    /**
     * Delete from the server
     */
    function destroy(env, typeName){
        return env.createClient().delete(asUrlPath(typeName), Views().status);
    }

    /**
     * Delete locally
     */
    function asFilePath(name){
        return path.join(process.cwd(), 'models', (name + '.json'));
    }

    function asUrlPath(name){
        return [ENDPOINT, name].join('/');
    }

    return {
        post    : create,
        update  : update,
        list    : list,
        get     : get,
        download: download,
        'delete': destroy,
        listProps: listProps
    }
};

==> bodhi-cli-0.7.10.tgz: package/lib/controllers/RemoteTypeController.js <==
module.exports = function(project, options){

    var _  = require('../utils.js')
        , path    = require('path')
        , fs      = require('fs-extra')
        , Views   = require('../views/http.js')
        ;

    var ENDPOINT = 'types';

    /**
     * Fetch the object from the server and write to a file
     */
    function save(env, typeName, opr){
        var client = env.createClient();
        try{
            var model = fs.readJsonFileSync(asFilePath(typeName));
            model.namespace = env.namespace;
            client[opr](ENDPOINT, model, function(err, response, body){
                if(err) {
                    console.log('operation failed');
                    return;
                }
                if(response.statusCode === 422){
                    console.log('operation returned ' + response.statusCode);
                    console.log(body);
                } else {
                    console.log('operation returned ' + response.statusCode);
                }
            });
        } catch (err){
            console.log('No such model %s', typeName)
        }
        //console.log(client.buildUri(asUrlPath(typeName)));
    }

    function create(env, typeName){
        return save(env, typeName, 'post');
    }

    function update(env, typeName){
        return save(env, typeName, 'put');
    }

    /**
     * Show a remote model
     * --should add the color option here
     */
    function get(env, typeName, spec){
        env.createClient().get(
            asUrlPath(typeName), Views(spec).entity
        );
    }

    /**
     * Fetch the object from the server and write to a file
     */
    function download(env, typeName){
        env.createClient().pull(asUrlPath(typeName), asFilePath(typeName));
        console.log(asFilePath(typeName));
    }

    /**
     * List the models
     */
    function list(env){
        env.createClient().get(ENDPOINT, function(err, response, body) {
            if(err){
                console.log("Error", err);
            } else {
                var json = JSON.parse(body);
                console.log(_.pluck(json, "name").sort());
            }
        });
    }

    function listProps(env, name){
        env.createClient().get(asUrlPath(name), function(err, response, body) {
                if(err){
                    console.log("Error", err);
                }
                var json = JSON.parse(body);
                var properties = [];
                _.forEach(json.properties, function(value, key, list){
                    if(!_.startsWith(key, 'sys_')){
                        console.log(key);
                    }
                })
        });
    }

    /**
     * Delete from the server
     */
    function destroy(env, typeName){
        return env.createClient().delete(asUrlPath(typeName), Views().status);
    }

    /**
     * Delete locally
     */
    function asFilePath(name){
        return path.join(process.cwd(), 'models', (name + '.json'));
    }

    function asUrlPath(name){
        return [ENDPOINT, name].join('/');
    }

    return {
        post     : create,
        update   : update,
        list     : list,
        listProps: listProps,
        get      : get,
        download : download,
        'delete' : destroy
    }
};
